@@ -47,6 +47,7 @@ class _MLP(nn.Module):
 
         lr (float): Learning rate. 
             Default: ``1e-4``
+            
     """
     def __init__(
         self,
@@ -162,6 +163,7 @@ class _MLP(nn.Module):
 
 class MLP(BaseNet):
     r"""Multi-layer perceptron with identical # of hidden units.
+
     """
     def __init__(
         self,
@@ -173,8 +175,6 @@ class MLP(BaseNet):
     ) -> None:
         r"""Multi-layer perceptron with identical # of hidden units.
 
-            The number of layers are specified with argument ``n_layers``.
-
             Args:
 
                 dims (int or tuple of int): The dimension of the data. e.g., 4, (8,8,1), (32,32,3)
@@ -204,6 +204,7 @@ class MLP(BaseNet):
 
                 lr (float): Learning rate. 
                     Default: ``1e-4``
+
         """
         
         entire_keys = [
@@ -266,6 +267,7 @@ class _ContractingMLP(nn.Module):
 
     _ContractingMLP and ContractingMLP are basically identical in structure. The only difference is that
     _ContractingMLP is an offspring of nn.Module and ContractingMLP is an offspring of BaseNet.
+
     """
     def __init__(
         self,
@@ -313,6 +315,7 @@ class _ContractingMLP(nn.Module):
 
                 lr (float): Learning rate. 
                     Default: ``1e-4``
+                    
     """
         super(_ContractingMLP, self).__init__()
 
@@ -469,6 +472,7 @@ class ContractingMLP(BaseNet):
 
     _ContractingMLP and ContractingMLP are basically identical in structure. The only difference is that
     _ContractingMLP is an offspring of nn.Module and ContractingMLP is an offspring of BaseNet.
+
     """
     def __init__(
         self,
@@ -506,6 +510,7 @@ class ContractingMLP(BaseNet):
 
                 lr (float): Learning rate. 
                     Default: ``1e-4``
+
         """
         
         entire_keys = [
@@ -572,28 +577,32 @@ class _CustomMLP(nn.Module):
     _CustomMLP and CustomMLP are basically identical in structure. The only difference is that
     _CustomMLP is an offspring of nn.Module and CustomMLP is an offspring of BaseNet.
 
-    Arguments:
-        - dims (Union[int, Tuple[int]]): The dimension of the data. e.g., 4, (8,8,1)
-
-        - n_classes (Optional[int]) : Number of classes (labels) in the classification task.
-                                        Do not specify this argument (set is as None) when you 
-                                    re performing regression tasks.
+    Args:
         
-        - n_hidden_units_list : Optional[List[int]] : List of all n_hidden_units for all hidden layers.
+        dims (Union[int, Tuple[int]]): The dimension of the data. e.g., 4, (8,8,1)
+
+        n_classes (Optional[int]) : Number of classes (labels) in the classification task.
+        
+        n_hidden_units_list : Optional[List[int]] : List of all n_hidden_units for all hidden layers.
                                                     If not specified, it would be an old-school perceptron.
 
-        - batch_size (int) : Batch size. Default : 64 (see utils_lightning.py)
+        batch_size (int) : Batch size. Default : 64 (see utils_lightning.py)
 
-        - optimizer_type (str) : Type of the optimizer. ("adam" or "sgd") Default : "adam" (see utils_lightning.py) 
-                                #TODO : implement other optimizers.(in model_base.py)
+        optimizer_type (str) : Type of the optimizer. ("adam" or "sgd") 
+            Default : ``"adam"`` 
 
-        - dropout_p (0<= float < 1) : Dropout probability Default : 0 (see utils_lightning.py)
+        dropout_p (float) : Dropout probability 
+            Default : ``0`` 
 
-        - bn (bool) : Whether to use batch normalization or not. Default : True (see utils_lightning.py)
+        bn (bool) : Whether to use batch normalization or not. 
+            Default : ``True`` 
 
-        - weight_decay (0<= float) : coefficient for L2-regularization. Default : 0 (see utils_lightning.py)
+        weight_decay (float) : coefficient for L2-regularization. 
+            Default : ``0`` 
+
+        lr (float) : Learning rate. 
+            Default: ``1e-4`` 
 
-        - lr ( 0 < float) : Learning rate. Default: 1e-4 (see utils_lightning.py)
     """
     def __init__(
         self,
@@ -1057,7 +1066,7 @@ class ResNet18(ConvNet):
         return self.model(X)
 
 class _UNet(nn.Module):
-    """
+    r"""
     Paper: `U-Net: Convolutional Networks for Biomedical Image Segmentation
     <https://arxiv.org/abs/1505.04597>`
     Args:
@@ -1066,6 +1075,7 @@ class _UNet(nn.Module):
         num_layers: Number of layers in each side of U-net (default 5)
         features_start: Number of features in first layer (default 64)
         bilinear: Whether to use bilinear interpolation or transposed convolutions (default) for upsampling.
+
     """
 
     def __init__(
